<?php
/*
Plugin Name: Ribbon
Description: Add a ribbon top right
Plugin URI: http://www.pivari.com/software/ribbon/
Author: Pivari.com
Author URI: http://www.pivari.com
Version: 1.0.0
License: GPL12
*/

// Function to add a menu page for the plugin
function setup_ribbon_plugin_menus() {
    add_menu_page(
        'Ribbon Settings',
        'Ribbon',
        'manage_options',
        'ribbon',
        'ribbon_page'
    );
}
// Hook to add the menu page
add_action('admin_menu', 'setup_ribbon_plugin_menus');

// Function to render the insert image page
function ribbon_page() {
    if (!current_user_can('manage_options')) {
        wp_die('You do not have sufficient permissions to access this page.');
    }

    // Check if settings form is submitted
    if (isset($_POST['update_settings'])) {
        $color = sanitize_text_field($_POST['color']);
        update_option('color', $color);
        $reduction = sanitize_text_field($_POST['reduction']);
        update_option('reduction', $reduction);
	$top = sanitize_text_field($_POST['top']);
        update_option('top', $top);
	$url = sanitize_text_field($_POST['url']);
        update_option('url', $url);
        $message = 'At the moment the ribbon color is ' . $color;
        $message .= '<br>At the moment the ribbon top distance is ' . $top;
        $message .= '<br>The original ribbon is 2000px x 2500px. The ribbon reduction set is ' . $reduction;
        $message .= '<br>The url cliccking on ribbon is ' . $url;
        echo '<div id="message" class="updated"><b>' . $message . '</b></div>';
    }

    // Get the current color and reduction from options
    $color = esc_attr(get_option('color'));
    $reduction = esc_attr(get_option('reduction'));
    $top = esc_attr(get_option('top'));
    $url = esc_attr(get_option('url'));

    // Set the default color to #FFFFFF black if it is not set
    if (empty($color)) {
        $color = '#FFFFFF';
    }
    if (empty($url)) {
        $url = 'https://www.pivari.com/';
    }
    // Set the default top distance to 0 if it is not set
    if (empty($top)) {
        $top = 0;
    }
    // Set the default reduction to 10 if it is not set
    if (empty($reduction)) {
        $reduction = 10;
    }

    

    // Render the settings page
    ob_start();
    ?>
    <div class="wrap">
        <h1>Ribbon Plugin Settings</h1>
        <p>Introduce the Ribbon color in hexadecimal: e.g. #FFFFF is white, #00000 is black, #FF0000 is red, #00FF00 is green and #0000FF is blue.<br>
        Introduce the Ribbon reduction, default is 10. The original ribbon dimension is 2000px x 2500px.<br>
        Introduce the Ribbon top distance, default is 0px.</p>
        <form method="POST" action="">
            <input type="hidden" name="update_settings" value="Y" />
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">
                        <label for="color">Color</label>
                    </th>
                    <td>
                        <input type="text" name="color" required value="<?php echo $color; ?>" size="16" />
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">
                        <label for="reduction">Reduction</label>
                    </th>
                    <td>
                        <input type="text" name="reduction" required value="<?php echo $reduction; ?>" size="16" />
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">
                        <label for="top">Top distance</label>
                    </th>
                    <td>
                        <input type="text" name="top" required value="<?php echo $top; ?>" size="16" />
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">
                        <label for="url">URL cliccking on Ribbon</label>
                    </th>
                    <td>
                        <input type="text" name="url" required value="<?php echo $url; ?>" size="30" />
                    </td>
                </tr>

            </table>
            <p>
                <input type="submit" value="Save settings" class="button-primary" />
            </p>
        </form>
    </div>
    <?php
    echo ob_get_clean();
}

// insert_image function to add the image after <body>
function ribbon() {
    $version = '1.0.0';
    $color = esc_attr(get_option('color'));
    $reduction = esc_attr(get_option('reduction'));
    $top = esc_attr(get_option('top'));
    $url = esc_attr(get_option('url'));
    $width = 2000;
    $height = 2500;
    $rwidth = $width / $reduction;
    $rheight = $height / $reduction;
    ob_start();
    ?>
    <!-- plugin ribbon <?php echo $version; ?> -->
    <a href="<?php echo $url; ?>"><svg style="position: fixed; z-index: 9999; right: 0; top: <?php echo $top; ?>;" xmlns="http://www.w3.org/2000/svg" width="<?php echo $rwidth; ?>" height="<?php echo $rheight; ?>" viewBox="39.39 1.172 324.975 406.495">
        <title>ribbon</title>
        <title>layer</title>
        <g fill="<?php echo $color; ?>" stroke="#FFFFFF" stroke-width="2">
            <path d="M151.036 14.728c25.248-10.863 49.059-12.879 83.902-2.032 4.07 4.166-3.577 48.009-3.577 48.009-30.696-14.182-48.263-17.126-78.959 3.312.001 0-12.595-39.276-1.366-49.289z"/>
            <path d="M148.884 15.616c15.829-18.318 83.555-16.483 100.39-3.109s27.662 100.138-4.28 73.443c-31.942-26.695-57.746-26.199-94.475 5.068 0 0-17.464-57.083-1.635-75.402z"/>
            <path d="M253.848 21.385s-4.317-35.721 22.636 63.323c26.955 99.044-137.336 313.352-154.053 313.352l-81.177-33.15C222.173 204.117 258.487 48.529 253.848 21.385z"/>
            <path d="M144.968 29.993s4.907-35.721-25.729 63.323C88.604 192.36 275.333 406.667 294.333 406.667l68.308-56.148C200.202 251.725 139.696 57.137 144.968 29.993z"/>
        </g>
    </svg></a>
    <?php
    echo ob_get_clean();
}

// Hook to add the function to the page after <body>
add_action('wp_body_open', 'ribbon');

